@@ -5,8 +5,8 @@ Compile XML to Python byte-code.
 
 from __future__ import generators
 
-__revision__ = "$Rev: 158 $"
-__date__ = "$Date: 2005-06-02 04:37:21 -0400 (Thu, 02 Jun 2005) $"
+__revision__ = "$Rev: 262 $"
+__date__ = "$Date: 2006-01-28 16:38:09 +0000 (Sat, 28 Jan 2006) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -151,7 +151,7 @@ class KidFile(object):
             return 1
 
 def _maybe_open(f, mode):
-    if isinstance(f, (str, unicode)):
+    if isinstance(f, basestring):
         return open(f, mode)
     else:
         return f
@@ -206,50 +206,3 @@ def compile_dir(dir, maxlevels=10, force=0, source=0, encoding=None, strip_dest_
                 yield rslt
     return
 
-class KidcUsageError(Exception):
-    pass
-
-def kidc(args):
-    from getopt import getopt, GetoptError as gerror
-    try:
-        opts, args = getopt(args[1:], 'fshd=', ['force', 'source', 'help', 'strip-dest-dir='])
-    except gerror, msg:
-        raise KidcUsageError(msg)
-    force = 0
-    source = 0
-    strip_dest_dir = None
-    for o, a in opts:
-        if o in ('-f', '--force'):
-            force = True
-        elif o in ('-s', '--source'):
-            source = True
-        elif o in ('-h', '--help'):
-            raise KidcUsageError('help')
-        elif o in ('-d', '--strip-dest-dir'):
-            strip_dest_dir = a
-    files = args
-    if len(files) == 0:
-        raise "Use 'kidc --help' for usage information."
-
-    # a quick function for printing results
-    def print_result(rslt):
-        (rslt, file) = rslt
-        if rslt == True:
-            msg = 'compile: %s\n' % file
-        elif rslt == False:
-            msg = 'fresh: %s\n' % file
-        else:
-            msg = 'error: %s (%s)\n' % (file, rslt)
-        sys.stderr.write(msg)
-
-    # run through files and compile
-    for f in files:
-        if os.path.isdir(f):
-            for rslt in compile_dir(f, force=force, source=source, strip_dest_dir=strip_dest_dir):
-                print_result(rslt)
-        else:
-            compile_file(f, force=force, source=source, strip_dest_dir=strip_dest_dir)
-            print_result((True, f))
-
-if __name__ == '__main__':
-    kidc(sys.argv)
