@@ -8,14 +8,44 @@ __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
 import os
 
-import elementtree.ElementTree as ET
-if not os.environ.get('KID_NOCET'):
-    try:
-        from cElementTree import *
-    except ImportError:
-        from elementtree.ElementTree import *
-else:
-    from elementtree.ElementTree import *
+# If allowed and possible, import all objects from CElementTree:
+
+try:
+    if os.environ.get('KID_NOCET'):
+        raise ImportError
+    else:
+        try:
+            if os.environ.get('KID_NOET'):
+                raise ImportError
+            else:
+                import cElementTree as CET
+                from cElementTree import *
+        except ImportError:
+            # you must have Python 2.5 or newer
+            import xml.etree.cElementTree as CET
+            from xml.etree.cElementTree import *
+except:
+    CET = None
+
+# Otherwise, import all objects from ElementTree:
+
+try:
+    if os.environ.get('KID_NOET'):
+        raise ImportError
+    else:
+        import elementtree.ElementTree as ET
+        if not CET:
+            from elementtree.ElementTree import *
+except ImportError:
+    # you must have Python 2.5 or newer
+    import xml.etree.ElementTree as ET
+    if not CET:
+        from xml.etree.ElementTree import *
+
+# These functions exist only in ET, not in CET:
+
+encode_entity = ET._encode_entity
+raise_serialization_error = ET._raise_serialization_error
 
 def Comment(text=None):
     elem = Element(Comment)
@@ -29,10 +59,13 @@ def ProcessingInstruction(target, text=None):
         element.text = element.text + " " + text
     return element
 
+# The fragment factory does not exist in ElementTree:
+
 def Fragment(text=''):
-    """Create an XML fragment.
+    """XML fragment factory.
 
     Fragments hold TEXT and children but do not have a tag or attributes.
+
     """
     elem = Element(Fragment)
     elem.text = text
@@ -52,9 +85,8 @@ def namespaces(elem, remove=0):
 
     If remove is truthful, namespace declaration attributes are removed
     from the passed in Element.
-    
+
     """
-    
     names = {}
     for k in elem.keys():
         if k.startswith('xmlns:'):
@@ -67,4 +99,5 @@ def namespaces(elem, remove=0):
 
 __all__ = ['Element', 'SubElement', 'Comment', 'ProcessingInstruction',
            'Fragment', 'ElementTree', 'QName', 'dump',
-           'parse', 'tostring', 'namespaces']
+           'parse', 'tostring', 'namespaces',
+           'encode_entity', 'raise_serialization_error']
