@@ -29,19 +29,19 @@ def apply_matches(stream, template, templates, apply_func):
                 (match, call) = templates[i]
                 if match(item):
                     item = stream.expand()
-                    newstream = _coalesce(call(template, item, apply_func), template._get_assume_encoding())
-                    if i+1 < len(templates):
-                        for ev, item in apply_matches(ElementStream(newstream),
-                                                      template,
-                                                      templates[i+1:],
-                                                      apply_func):
-                            yield ev, item
-                    else:
+                    newstream = _coalesce(call(template, item, apply_func),
+                        template._get_assume_encoding())
+                    if len(templates) < 2:
                         for ev, item in newstream:
                             yield (ev, item)
+                    else:
+                        for ev, item in apply_matches(ElementStream(newstream),
+                            template, templates[:i] + templates[i+1:], apply_func):
+                                yield ev, item
                     matched = 1
                     break
-            if matched: continue
+            if matched:
+                continue
         yield (ev, item)
 
 # XXX haven't tested this yet..
@@ -63,4 +63,3 @@ def xinclude_filter(stream, template):
                 for ev, item in doc:
                     if ev != XML_DECL:
                         yield ev
-            
