@@ -25,17 +25,20 @@ class Namespace(object):
     
     def __str__(self):
         return self.uri
+
     def __unicode__(self):
         return unicode(self.uri)
+
     def __repr__(self):
         return 'Namespace(%r, %r)' % (self.uri, self.prefix)
+
     def __equals__(self, other):
         if isinstance(other, basestring):
             return self.uri == other
         elif isinstance(other, Namespace):
             return self.uri == other.uri
         else:
-            return 0
+            return False
     
 xml = Namespace('http://www.w3.org/XML/1998/namespace', 'xml')
 xhtml = Namespace('http://www.w3.org/1999/xhtml', 'html')
