@@ -5,8 +5,8 @@ Parses Kid embedded XML to Python source code.
 
 from __future__ import generators
 
-__revision__ = "$Rev: 307 $"
-__date__ = "$Date: 2006-04-06 11:59:35 +0000 (Thu, 06 Apr 2006) $"
+__revision__ = "$Rev: 346 $"
+__date__ = "$Date: 2006-06-20 11:09:56 +0000 (Tue, 20 Jun 2006) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -140,7 +140,7 @@ class KidParser(object):
                     if text.startswith('<') or text.startswith('['):
                         sub = interpolate(item.text)
                         if isinstance(sub, list):
-                            text = "''.join(%r)" % sub
+                            text = "''.join([unicode(o) for o in %r])" % sub
                         else:
                             text = repr(sub)
                     else:
@@ -308,8 +308,7 @@ class KidParser(object):
                 self.attrib_proc(item, attrib, code)
                 end_block()
             else:
-                # element is always stripped
-                pass
+                pass # element is always stripped
         else:
             self.attrib_proc(item, attrib, code)
         if has_content:
@@ -318,8 +317,6 @@ class KidParser(object):
             line('yield _e')
             line('del _e')
             code.end_block()
-            # XXX should we use the hardcoded content if py:content is
-            # specified but returns None?
             self.stream.eat()
         else:
             self.depth += 1
