@@ -36,21 +36,21 @@ class Serializer(object):
 
     namespaces = namespace.namespaces
     encoding = 'utf-8'
-    balanced_blocks = 1
+    balanced_blocks = False
     strip_whitespace = 0
-    
+
     def __init__(self, encoding=None, src_encoding="utf-8"):
         if encoding is not None:
             self.encoding = encoding
         self.src_encoding = src_encoding
-        
+
     def has_only_pcdata(self, tagname):
         return False
 
     def serialize(self, stream, encoding=None, fragment=0):
         text = list(self.generate(stream, encoding, fragment))
         return ''.join(text)
-    
+
     def write(self, stream, file, encoding=None, fragment=0):
         needs_closed = False
         if not hasattr(file, 'write'):
@@ -110,13 +110,13 @@ class Serializer(object):
                 yield (TEXT, item.strip())
             else:
                 yield (ev, item)
-        
+
 class XMLSerializer(Serializer):
 
     decl = 1
     doctype = None
     cdata_elements = []
-    
+
     def __init__(self, encoding=None, decl=None, doctype=None,
                  namespaces=None):
         Serializer.__init__(self, encoding)
@@ -129,22 +129,22 @@ class XMLSerializer(Serializer):
             self.doctype = doctypes[self.doctype]
         if namespaces:
             self.namespaces = namespaces
-    
+
     def can_be_empty_element(self, ns_stack, item_name):
         return True
-    
+
     def generate(self, stream, encoding=None, fragment=0):
         """Serializes an event stream to bytes of the specified encoding.
-        
+
         This function yields an encoded string over and over until the
         stream is exhausted.
-        
+
         """
-        
+
         encoding = encoding or self.encoding or 'utf-8'
         escape_cdata = XMLSerializer.escape_cdata
         escape_attrib = XMLSerializer.escape_attrib
-        
+
         lastev = None
         stream = iter(stream)
         names = NamespaceStack(self.namespaces)
@@ -206,7 +206,7 @@ class XMLSerializer(Serializer):
                 names.pop()
             lastev = ev
         return
-    
+
     def escape_cdata(text, encoding=None):
         """Escape character data."""
         try:
@@ -214,12 +214,12 @@ class XMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return _encode_entity(text)
+                    return encode_entity(text)
             text = text.replace("&", "&amp;")
             text = text.replace("<", "&lt;")
             return text
         except (TypeError, AttributeError):
-            _raise_serialization_error(text)
+            raise_serialization_error(text)
     escape_cdata = staticmethod(escape_cdata)
 
     def escape_attrib(text, encoding=None):
@@ -229,15 +229,15 @@ class XMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return _encode_entity(text)
+                    return encode_entity(text)
             text = text.replace("&", "&amp;")
             text = text.replace("<", "&lt;")
             text = text.replace("\"", "&quot;")
             return text
         except (TypeError, AttributeError):
-            _raise_serialization_error(text)
+            raise_serialization_error(text)
     escape_attrib = staticmethod(escape_attrib)
-    
+
 
 # sets
 try:
@@ -268,7 +268,7 @@ class HTMLSerializer(Serializer):
     boolean_attributes = set(['selected', 'checked', 'compact', 'declare',
                           'defer', 'disabled', 'ismap', 'multiple', 'nohref',
                           'noresize', 'noshade', 'nowrap'])
-    
+
     def __init__(self, encoding='utf-8', doctype=None, transpose=None):
         Serializer.__init__(self, encoding)
         if doctype:
@@ -281,25 +281,25 @@ class HTMLSerializer(Serializer):
 
     def has_only_pcdata(self, tagname):
         if isinstance(tagname, basestring) and tagname[0] == '{':
-            tagname = tagname.split('}')[1] 
+            tagname = tagname.split('}')[1]
         return tagname in self.elements_with_pcdata
 
     def generate(self, stream, encoding=None, fragment=0):
         """Serializes an event stream to bytes of the specified encoding.
-        
+
         This function yields an encoded string over and over until the
         stream is exhausted.
-        
+
         """
-        
+
         encoding = encoding or self.encoding or 'utf-8'
-        
+
         escape_cdata = HTMLSerializer.escape_cdata
         escape_attrib = HTMLSerializer.escape_attrib
         noescape_elements = self.noescape_elements
         boolean_attributes = self.boolean_attributes
         empty_elements = self.empty_elements
-        
+
         names = NamespaceStack(self.namespaces)
 
         def grok_name(tag):
@@ -315,10 +315,12 @@ class HTMLSerializer(Serializer):
                     qname = self.transpose(qname)
             return (uri, localname, qname)
 
+        attr_http_equiv = 'http-equiv'
+        attr_content = 'content'
         if self.transpose:
             attr_http_equiv = self.transpose('http-equiv')
             attr_content = self.transpose('content')
-        
+
         current = None
         stack = [current]
         stream = iter(stream)
@@ -343,11 +345,11 @@ class HTMLSerializer(Serializer):
                     names.push(namespaces(item, remove=1))
                     tag = item.tag
                     (uri, localname, qname) = grok_name(tag)
-                    
+
                     # push this name on the stack so we know where we are
                     current = qname.lower()
                     stack.append(current)
-                    
+
                     yield "<" + qname.encode(encoding)
                     attrs = item.attrib.items()
                     if attrs:
@@ -365,14 +367,14 @@ class HTMLSerializer(Serializer):
                     yield ">"
                     if self.inject_type:
                         if current == 'head':
-                            (uri, localname, qname) = grok_name("meta") 
+                            (uri, localname, qname) = grok_name("meta")
                             yield '<%s %s="text/html; charset=%s"' \
                                   ' %s="Content-Type">' \
                                   % (qname.encode(encoding),
                                      attr_content,
                                      encoding,
                                      attr_http_equiv)
-                        
+
             elif ev == END and item.tag not in (Comment,
                                                 ProcessingInstruction,
                                                 Fragment):
@@ -392,15 +394,15 @@ class HTMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return _encode_entity(text)
+                    return encode_entity(text)
             if escape:
                 text = text.replace("&", "&amp;")
                 text = text.replace("<", "&lt;")
             return text
         except (TypeError, AttributeError):
-            _raise_serialization_error(text)
+            raise_serialization_error(text)
     escape_cdata = staticmethod(escape_cdata)
-    
+
     def escape_attrib(text, encoding=None):
         """Escape attribute value."""
         try:
@@ -408,18 +410,18 @@ class HTMLSerializer(Serializer):
                 try:
                     text = text.encode(encoding)
                 except UnicodeError:
-                    return _encode_entity(text)
+                    return encode_entity(text)
             text = text.replace("&", "&amp;")
             text = text.replace("\"", "&quot;")
             return text
         except (TypeError, AttributeError):
-            _raise_serialization_error(text)
+            raise_serialization_error(text)
     escape_attrib = staticmethod(escape_attrib)
 
 class XHTMLSerializer(XMLSerializer):
     empty_elements = [namespace.xhtml.clarkname(name) for name in HTMLSerializer.empty_elements]
     elements_with_pcdata = [namespace.xhtml.clarkname(name) for name in HTMLSerializer.elements_with_pcdata]
-    
+
     def can_be_empty_element(self, ns_stack, tagname):
         return tagname in self.empty_elements
 
@@ -437,29 +439,31 @@ class PlainSerializer(Serializer):
 
 
 class NamespaceStack:
-    
+
     """Maintains a stack of namespace prefix to URI mappings."""
-    
+
     def __init__(self, default_map=namespace.namespaces):
         self.stack = []
         self.default_map = default_map
         self.push()
         self.ns_count = 0
-        
+
     def push(self, names=None):
         if names is None:
             names = {}
         self.current = names
         self.stack.insert(0, self.current)
-        
+
     def pop(self):
+        ns = self.stack[0]
         del self.stack[0]
-        if len(self.stack):
+        if self.stack:
             self.current = self.stack[0]
-        
+        return ns
+
     def resolve_prefix(self, uri, default=1):
         """Figure out prefix given a URI."""
-        
+
         if uri == 'http://www.w3.org/XML/1998/namespace':
             return 'xml'
         # first check if the default is correct
@@ -482,10 +486,10 @@ class NamespaceStack:
             return prefix
         else:
             return None
-    
+
     def resolve_uri(self, prefix):
         """Figure out URI given a prefix."""
-        
+
         if prefix == 'xml':
             return 'http://www.w3.org/XML/1998/namespace'
         for names in self.stack:
@@ -493,7 +497,7 @@ class NamespaceStack:
             if uri:
                 return uri
         return None
-    
+
     def qname(self, cname, default=0):
         if isinstance(cname, QName):
             cname = cname.text
@@ -520,18 +524,6 @@ class NamespaceStack:
             return '%s:%s' % (prefix, localname)
         else:
             return localname
-        
-    def set(self, prefix, uri):
-        if prefix is None:
-            prefix = ''
-        self.current[prefix] = uri
-
-
-
-# utility functions for escaping XML cdata and attributes
-from kid.et import ET
-_encode_entity = ET._encode_entity
-_raise_serialization_error = ET._raise_serialization_error
 
 def serialize_doctype(doctype):
     return '<!DOCTYPE %s PUBLIC "%s" "%s">' % doctype
