@@ -8,14 +8,16 @@ __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
 
 import os
+import glob
 from os.path import dirname, basename, join, abspath
 
-template_dir = abspath(join(dirname(__file__), '../../test'))
+_mydir = abspath(join(dirname(__file__))) + '/../../'
+template_dir = _mydir + 'test'
 output_dir = template_dir
 template_package = 'test.'
 
-test_modules = ['test_namespace', 'test_pull', 'test_compiler', 'test_parser',
-                'test_kid', 'test_serialization', 'test_comment', 'test_layout']
+test_modules = [basename(f)[:-3] for f in
+    glob.glob(_mydir + 'kid/test/test*.py')]
 
 additional_tests = 0
 basic_tests = 0
