@@ -6,9 +6,7 @@ __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
-
 import kid
-from elementtree import ElementTree
 
 def test_interpolate_expr():
     from kid.parser import interpolate
@@ -60,8 +58,3 @@ def test_exec_hack():
     """Guido may break this some day.."""
     exec('x = 10')
     assert x == 10
-
-__tests__ = [test_interpolate_expr,
-             test_interpolate_object,
-             test_adjust_block,
-             test_exec_hack]
