@@ -18,10 +18,10 @@ def test_html_output_method():
     rslt = t.serialize(output='html')
     expected = serialize_doctype(doctypes['html']) + \
                '\n<HTML><P>test</P><BR></HTML>'
-    
+
     print rslt
     assert rslt == expected
-    
+
 def test_xhtml_output_method():
     t = kid.Template('<html xmlns="http://www.w3.org/1999/xhtml">'
             '<p>test</p><img src="some.gif" /><br /></html>')
@@ -29,16 +29,16 @@ def test_xhtml_output_method():
     expected = serialize_doctype(doctypes['xhtml']) \
                + '\n<html xmlns="http://www.w3.org/1999/xhtml"><p>test</p>' \
                + '<img src="some.gif" /><br /></html>'
-    
+
     print rslt
     assert rslt == expected
-    
+
 def test_html_strict_output_method():
     t = kid.Template('<html><p>test</p><br /></html>')
     rslt = t.serialize(output='html-strict')
     expected = serialize_doctype(doctypes['html-strict']) + \
                '\n<HTML><P>test</P><BR></HTML>'
-    
+
     print rslt
     assert rslt == expected
 
@@ -51,11 +51,11 @@ def test_xml_output_method():
     assert rslt == expected
 
 
-from kid.serialization import HTMLSerializer
+from kid.serialization import HTMLSerializer, XMLSerializer
 serializer = HTMLSerializer()
 serializer.doctype = None
 serializer.inject_type = 0
-    
+
 def HTMLTemplate(text, **kw):
     t = kid.Template(source=text, **kw)
     t.serializer = serializer
@@ -150,13 +150,57 @@ def test_comment_whitespace():
             '<!-- a comment -->\n<element>\n</element>\n</html>'
     assert kid.Template(expected).serialize(output='xhtml') == expected
 
-__tests__ = [test_xml_output_method,
-             test_html_output_method,
-             test_html_strict_output_method,
-             test_html_empty_elements,
-             test_html_noescape_elements,
-             test_html_boolean_attributes,
-             test_doctype_and_injection,
-             test_strip_lang,
-             test_transpose_lower,
-             test_transpose_off]
+def test_empty_textarea():
+    """Empty TEXTAREAs should not be indented like other elements."""
+    t = kid.Template('<html><textarea></textarea></html>')
+
+    expected = serialize_doctype(doctypes['html']) + \
+                '\n<HTML><TEXTAREA></TEXTAREA></HTML>'
+    assert t.serialize(output='html') == expected
+
+    expected = serialize_doctype(doctypes['xhtml']) + \
+                '\n<html><textarea></textarea></html>'
+    assert t.serialize(output='xhtml') == expected
+
+def test_whitespace():
+    """Empty lines between elements should be removed.
+    Inline elements in template should remain so.
+    Other elements should be indented"""
+    t = kid.Template("""
+<html>
+<script>some
+lines
+  
+and more lines</script><body>
+ <a href="/"><img src=""/></a>
+</body>
+
+  </html>""")
+
+    expected = serialize_doctype(doctypes['html']) + """
+<HTML>
+<SCRIPT>some
+lines
+  
+and more lines</SCRIPT><BODY>
+ <A HREF="/"><IMG SRC=""></A>
+</BODY>
+
+  </HTML>"""
+    print `t.serialize(output='html')`
+    print `expected`
+    assert t.serialize(output='html') == expected
+
+    expected = serialize_doctype(doctypes['xhtml']) + """
+<html>
+<script>some
+lines
+  
+and more lines</script><body>
+ <a href="/"><img src=""></img></a>
+</body>
+
+  </html>"""
+    print t.serialize(output='xhtml'),  expected
+    assert t.serialize(output='xhtml') == expected
+
